@@ -73,7 +73,10 @@ class LutrisWindow(Gtk.ApplicationWindow):  # pylint: disable=too-many-public-me
         update_desktop_icons()
         load_icon_theme()
         self.application = application
-
+        self.window_x = settings.read_setting("window_x")
+        self.window_y = settings.read_setting("window_y")
+        if self.window_x and self.window_y:
+            self.move(int(self.window_x), int(self.window_y))
         self.threads_stoppers = []
         self.window_size = (width, height)
         self.maximized = settings.read_setting("maximized") == "True"
@@ -88,7 +91,8 @@ class LutrisWindow(Gtk.ApplicationWindow):  # pylint: disable=too-many-public-me
         self.view = Gtk.Box()
 
         self.connect("delete-event", self.on_window_delete)
-        self.connect("map-event", self.on_load)
+        self.connect("configure-event", self.on_window_configure)
+        self.connect("realize", self.on_load)
         if self.maximized:
             self.maximize()
 
@@ -188,7 +192,7 @@ class LutrisWindow(Gtk.ApplicationWindow):  # pylint: disable=too-many-public-me
     def service_media(self):
         return self.get_service_media(self.load_icon_type())
 
-    def on_load(self, widget, data):
+    def on_load(self, widget, data=None):
         """Finish initializing the view"""
         self.redraw_view()
         self._bind_zoom_adjustment()
@@ -409,7 +413,12 @@ class LutrisWindow(Gtk.ApplicationWindow):  # pylint: disable=too-many-public-me
             self.game_bar = GameBar(game, self.game_actions, self.application)
             self.revealer_box.pack_start(self.game_bar, True, True, 0)
         elif self.game_bar:
-            self.game_bar.destroy()
+            # The game bar can't be destroyed here because the game gets unselected on Wayland
+            # whenever the game bar is interacted with. Instead, we keep the current game bar open
+            # when the game gets unselected, which is somewhat closer to what the intended behavior
+            # should be anyway. Might require closing the game bar manually in some cases.
+            pass
+            # self.game_bar.destroy()
         if self.revealer_box.get_children():
             self.game_revealer.set_reveal_child(True)
         else:
@@ -621,6 +630,10 @@ class LutrisWindow(Gtk.ApplicationWindow):  # pylint: disable=too-many-public-me
             self.hide()
             return True
 
+    def on_window_configure(self, *_args):
+        """Callback triggered when the window is moved, resized..."""
+        self.window_x, self.window_y = self.get_position()
+
     @GtkTemplate.Callback
     def on_destroy(self, *_args):
         """Signal for window close."""
@@ -632,6 +645,9 @@ class LutrisWindow(Gtk.ApplicationWindow):  # pylint: disable=too-many-public-me
         width, height = self.window_size
         settings.write_setting("width", width)
         settings.write_setting("height", height)
+        if self.window_x and self.window_y:
+            settings.write_setting("window_x", self.window_x)
+            settings.write_setting("window_y", self.window_y)
         settings.write_setting("maximized", self.maximized)
 
     @GtkTemplate.Callback
