@@ -5,7 +5,7 @@ from lutris.database.games import PGA_DB, get_games, sql
 def migrate():
     """Run migration"""
     for game in get_games():
-        if not game["steamid"]:
+        if not game.get("steamid"):
             continue
         if game["runner"] and game["runner"] != "steam":
             continue
