@@ -1,17 +1,20 @@
 """Steam for Linux runner"""
+# Standard Library
 import os
-import time
 import subprocess
+import time
+from gettext import gettext as _
 
+# Lutris Modules
+from lutris.command import MonitoredCommand
 from lutris.runners import NonInstallableRunnerError
 from lutris.runners.runner import Runner
-from lutris.command import MonitoredCommand
-from lutris.util.log import logger
 from lutris.util import system
-from lutris.util.strings import split_arguments
-from lutris.util.steam.config import get_default_acf, read_config
-from lutris.util.steam.vdf import to_vdf
+from lutris.util.log import logger
 from lutris.util.steam.appmanifest import get_path_from_appmanifest
+from lutris.util.steam.config import STEAM_DATA_DIRS, get_default_acf, get_steam_dir, read_config
+from lutris.util.steam.vdf import to_vdf
+from lutris.util.strings import split_arguments
 
 
 def shutdown():
@@ -37,16 +40,16 @@ def is_running():
 
 
 class steam(Runner):
-    description = "Runs Steam for Linux games"
-    human_name = "Steam"
-    platforms = ["Linux"]
+    description = _("Runs Steam for Linux games")
+    human_name = _("Steam")
+    platforms = [_("Linux")]
     runner_executable = "steam"
     game_options = [
         {
             "option": "appid",
-            "label": "Application ID",
+            "label": _("Application ID"),
             "type": "string",
-            "help": (
+            "help": _(
                 "The application ID can be retrieved from the game's "
                 "page at steampowered.com. Example: 235320 is the "
                 "app ID for <i>Original War</i> in: \n"
@@ -56,47 +59,47 @@ class steam(Runner):
         {
             "option": "args",
             "type": "string",
-            "label": "Arguments",
-            "help": (
+            "label": _("Arguments"),
+            "help": _(
                 "Command line arguments used when launching the game.\n"
                 "Ignored when Steam Big Picture mode is enabled."
             ),
         },
         {
             "option": "run_without_steam",
-            "label": "DRM free mode (Do not launch Steam)",
+            "label": _("DRM free mode (Do not launch Steam)"),
             "type": "bool",
             "default": False,
             "advanced": True,
-            "help": (
+            "help": _(
                 "Run the game directly without Steam, requires the game binary path to be set"
             ),
         },
         {
             "option": "steamless_binary",
             "type": "file",
-            "label": "Game binary path",
+            "label": _("Game binary path"),
             "advanced": True,
-            "help": "Path to the game executable (Required by DRM free mode)",
+            "help": _("Path to the game executable (Required by DRM free mode)"),
         },
     ]
     runner_options = [
         {
             "option": "quit_steam_on_exit",
-            "label": "Stop Steam after game exits",
+            "label": _("Stop Steam after game exits"),
             "type": "bool",
             "default": False,
-            "help": (
+            "help": _(
                 "Shut down Steam after the game has quit\n"
                 "(only if Steam was started by Lutris)"
             ),
         },
         {
             "option": "start_in_big_picture",
-            "label": "Start Steam in Big Picture mode",
+            "label": _("Start Steam in Big Picture mode"),
             "type": "bool",
             "default": False,
-            "help": (
+            "help": _(
                 "Launches Steam in Big Picture mode.\n"
                 "Only works if Steam is not running or "
                 "already running in Big Picture mode.\n"
@@ -105,10 +108,10 @@ class steam(Runner):
         },
         {
             "option": "steam_native_runtime",
-            "label": "Disable Steam Runtime (use native libraries)",
+            "label": _("Disable Steam Runtime (use native libraries)"),
             "type": "bool",
             "default": False,
-            "help": (
+            "help": _(
                 "Launches Steam with STEAM_RUNTIME=0. "
                 "Make sure you disabled Lutris Runtime and "
                 "have the required libraries installed."
@@ -116,10 +119,10 @@ class steam(Runner):
         },
         {
             "option": "lsi_steam",
-            "label": "Start Steam with LSI",
+            "label": _("Start Steam with LSI"),
             "type": "bool",
             "default": False,
-            "help": (
+            "help": _(
                 "Launches steam with LSI patches enabled. "
                 "Make sure Lutris Runtime is disabled and "
                 "you have LSI installed. "
@@ -129,16 +132,16 @@ class steam(Runner):
         {
             "option": "args",
             "type": "string",
-            "label": "Arguments",
+            "label": _("Arguments"),
             "advanced": True,
-            "help": ("Extra command line arguments used when " "launching Steam"),
+            "help": _("Extra command line arguments used when launching Steam"),
         },
     ]
     system_options_override = [{"option": "disable_runtime", "default": True}]
 
     def __init__(self, config=None):
         super(steam, self).__init__(config)
-        self.own_game_remove_method = "Remove game data (through Steam)"
+        self.own_game_remove_method = _("Remove game data (through Steam)")
         self.no_game_remove_warning = True
         self.original_steampid = None
 
@@ -150,21 +153,9 @@ class steam(Runner):
     def appid(self):
         return self.game_config.get("appid") or ""
 
-    @property
-    def browse_dir(self):
-        """Return the path to open with the Browse Files action."""
-        if not self.is_installed():
-            installed = self.install_dialog()
-            if not installed:
-                return False
-        return self.game_path
-
     def get_steam_config(self):
         """Return the "Steam" part of Steam's config.vdf as a dict."""
-        steam_data_dir = self.steam_data_dir
-        if not steam_data_dir:
-            return None
-        return read_config(steam_data_dir)
+        return read_config(self.steam_data_dir)
 
     @property
     def game_path(self):
@@ -174,19 +165,8 @@ class steam(Runner):
 
     @property
     def steam_data_dir(self):
-        """Return dir where Steam files lie."""
-        candidates = (
-            "~/.steam",
-            "~/.local/share/steam",
-            "~/.steam/steam",
-            "~/.var/app/com.valvesoftware.Steam/data/steam",
-        )
-        for candidate in candidates:
-            path = system.fix_path_case(
-                os.path.join(os.path.expanduser(candidate), "SteamApps")
-            )
-            if path:
-                return path[: -len("SteamApps")]
+        """Main installation directory for Steam"""
+        return get_steam_dir()
 
     def get_executable(self):
         if system.LINUX_SYSTEM.is_flatpak:
@@ -239,11 +219,13 @@ class steam(Runner):
     def get_steamapps_dirs(self):
         """Return a list of the Steam library main + custom folders."""
         dirs = []
-
+        # Extra colon-separated compatibility tools dirs environment variable
+        if 'STEAM_EXTRA_COMPAT_TOOLS_PATHS' in os.environ:
+            dirs += os.getenv('STEAM_EXTRA_COMPAT_TOOLS_PATHS').split(':')
         # Main steamapps dir and compatibilitytools.d dir
-        if self.steam_data_dir:
-            for _dir in ["SteamApps", "compatibilitytools.d"]:
-                abs_dir = os.path.join(self.steam_data_dir, _dir)
+        for data_dir in STEAM_DATA_DIRS:
+            for _dir in ["steamapps", "compatibilitytools.d"]:
+                abs_dir = os.path.join(os.path.expanduser(data_dir), _dir)
                 abs_dir = system.fix_path_case(abs_dir)
                 if abs_dir and os.path.isdir(abs_dir):
                     dirs.append(abs_dir)
@@ -253,12 +235,20 @@ class steam(Runner):
         if steam_config:
             i = 1
             while "BaseInstallFolder_%s" % i in steam_config:
-                path = steam_config["BaseInstallFolder_%s" % i] + "/SteamApps"
+                path = steam_config["BaseInstallFolder_%s" % i] + "/steamapps"
                 path = system.fix_path_case(path)
                 if path and os.path.isdir(path):
                     dirs.append(path)
                 i += 1
-        return dirs
+
+        # Deduplicate directories with the same Device.Inode
+        unique_dirs = {}
+        for _dir in dirs:
+            stat = os.stat(_dir)
+            identifier = "{device}.{inode}".format(device=stat.st_dev, inode=stat.st_ino)
+            if identifier not in unique_dirs:
+                unique_dirs[identifier] = _dir
+        return unique_dirs.values()
 
     def get_default_steamapps_path(self):
         steamapps_paths = self.get_steamapps_dirs()
@@ -292,7 +282,7 @@ class steam(Runner):
 
     def prelaunch(self):
         def has_steam_shutdown(times=10):
-            for _ in range(times):
+            for __ in range(times):
                 time.sleep(1)
                 if not is_running():
                     return True
