@@ -26,8 +26,8 @@ from lutris.util.wine.prefix import WinePrefixManager, find_prefix
 from lutris.util.wine.wine import (
     POL_PATH, WINE_DIR, WINE_PATHS, detect_arch, display_vulkan_error, esync_display_limit_warning,
     esync_display_version_warning, fsync_display_support_warning, fsync_display_version_warning, get_default_version,
-    get_overrides_env, get_real_executable, get_system_wine_version, get_wine_versions, is_esync_limit_set,
-    is_fsync_supported, is_version_esync, is_version_fsync
+    get_overrides_env, get_proton_paths, get_real_executable, get_system_wine_version, get_wine_versions,
+    is_esync_limit_set, is_fsync_supported, is_gstreamer_build, is_version_esync, is_version_fsync
 )
 from lutris.util.wine.x360ce import X360ce
 
@@ -115,8 +115,8 @@ class wine(Runner):
         def get_wine_version_choices():
             version_choices = [(_("Custom (select executable below)"), "custom")]
             labels = {
-                "winehq-devel": _("WineHQ devel ({})"),
-                "winehq-staging": _("WineHQ staging ({})"),
+                "winehq-devel": _("WineHQ Devel ({})"),
+                "winehq-staging": _("WineHQ Staging ({})"),
                 "wine-development": _("Wine Development ({})"),
                 "system": _("System ({})"),
             }
@@ -133,14 +133,13 @@ class wine(Runner):
         def dxvk_choices(manager_class):
             version_choices = [
                 (_("Manual"), "manual"),
-                (manager_class.DXVK_LATEST, manager_class.DXVK_LATEST),
             ]
-            for version in manager_class.DXVK_PAST_RELEASES:
+            for version in manager_class.versions:
                 version_choices.append((version, version))
             return version_choices
 
         def get_dxvk_choices():
-            return dxvk_choices(dxvk.DXVKManager)
+            return dxvk_choices(dxvk.DXVKManager())
 
         def esync_limit_callback(widget, option, config):
             limits_set = is_esync_limit_set()
@@ -227,16 +226,8 @@ class wine(Runner):
                 "advanced": True,
                 "type": "choice_with_entry",
                 "choices": get_dxvk_choices,
-                "default": dxvk.DXVKManager.DXVK_LATEST,
+                "default": dxvk.DXVKManager().version,
             },
-            # Disabled until we get a working implementation if this option.
-            # {
-            #     "option": "dvxk_d3d9",
-            #     "label": _("Enable DX9 in DXVK"),
-            #     "type": "bool",
-            #     "default": True,
-            #     "help": _("Use DXVK to handle DirectX9 games")
-            # },
             {
                 "option": "esync",
                 "label": _("Enable Esync"),
@@ -287,7 +278,7 @@ class wine(Runner):
             },
             {
                 "option": "x360ce-dinput",
-                "label": _("x360ce dinput 8 mode"),
+                "label": _("x360ce DInput 8 mode"),
                 "type": "bool",
                 "default": False,
                 "help": _("Configure x360ce with dinput8.dll, required for some games"),
@@ -295,7 +286,7 @@ class wine(Runner):
             },
             {
                 "option": "x360ce-xinput9",
-                "label": _("x360ce xinput 9.1.0 mode"),
+                "label": _("x360ce XInput 9.1.0 mode"),
                 "type": "bool",
                 "default": False,
                 "help": _("Configure x360ce with xinput9_1_0.dll, required for some newer games"),
@@ -303,7 +294,7 @@ class wine(Runner):
             },
             {
                 "option": "dumbxinputemu",
-                "label": _("Use Dumb xinput Emulator (experimental)"),
+                "label": _("Use Dumb XInput Emulator (experimental)"),
                 "type": "bool",
                 "default": False,
                 "help": _("Use the dlls from kozec/dumbxinputemu"),
@@ -311,12 +302,12 @@ class wine(Runner):
             },
             {
                 "option": "xinput-arch",
-                "label": _("Xinput architecture"),
+                "label": _("XInput architecture"),
                 "type": "choice",
                 "choices": [
-                    (_("Same as wine prefix"), ""),
-                    (_("32 bit"), "win32"),
-                    (_("64 bit"), "win64"),
+                    (_("Same as Wine prefix"), ""),
+                    (_("32-bit"), "win32"),
+                    (_("64-bit"), "win64"),
                 ],
                 "default": "",
                 "advanced": True,
@@ -402,9 +393,8 @@ class wine(Runner):
                 "help": _(
                     "This option ensures any pending drawing operations are "
                     "submitted to the driver, but at a significant performance "
-                    'cost. Set to "enabled" to enable. This setting is deprecated '
-                    "since wine-2.6 and will likely be removed after wine-3.0. "
-                    'Use "csmt" instead.'
+                    "cost. This setting is deprecated since Wine-2.6 and will "
+                    'likely be removed after Wine-3.0. Use "csmt" instead.'
                 ),
             },
             {
@@ -458,7 +448,7 @@ class wine(Runner):
                 "type": "bool",
                 "default": False,
                 "advanced": True,
-                "help": _('Set this to "Y" to allow wine switch the resolution using XVidMode extension.'),
+                "help": _('Set this to "Y" to allow Wine switch the resolution using XVidMode extension.'),
             },
             {
                 "option":
@@ -527,7 +517,7 @@ class wine(Runner):
                 "type":
                 "bool",
                 "label":
-                _("Create a sandbox for wine folders"),
+                _("Create a sandbox for Wine folders"),
                 "default":
                 True,
                 "advanced":
@@ -550,14 +540,14 @@ class wine(Runner):
     @property
     def context_menu_entries(self):
         """Return the contexual menu entries for wine"""
-        menu_entries = [("wineexec", _("Run EXE inside wine prefix"), self.run_wineexec)]
+        menu_entries = [("wineexec", _("Run EXE inside Wine prefix"), self.run_wineexec)]
         if "Proton" not in self.get_version():
             menu_entries.append(("winecfg", _("Wine configuration"), self.run_winecfg))
         menu_entries += [
             ("wineshell", _("Open Bash terminal"), self.run_wine_terminal),
             ("wineconsole", _("Open Wine console"), self.run_wineconsole),
             ("wine-regedit", _("Wine registry"), self.run_regedit),
-            ("winekill", _("Kill all wine processes"), self.run_winekill),
+            ("winekill", _("Kill all Wine processes"), self.run_winekill),
             ("winetricks", _("Winetricks"), self.run_winetricks),
             ("winecpl", _("Wine Control Panel"), self.run_winecpl),
         ]
@@ -626,6 +616,10 @@ class wine(Runner):
         # logger.debug("Getting path for Wine %s", version)
         if version in WINE_PATHS.keys():
             return system.find_executable(WINE_PATHS[version])
+        if "Proton" in version:
+            for proton_path in get_proton_paths():
+                if os.path.isfile(os.path.join(proton_path, version, "dist/bin/wine")):
+                    return os.path.join(proton_path, version, "dist/bin/wine")
         if version.startswith("PlayOnLinux"):
             version, arch = version.split()[1].rsplit("-", 1)
             return os.path.join(POL_PATH, "wine", "linux-" + arch, version, "bin/wine")
@@ -839,14 +833,13 @@ class wine(Runner):
         self.sandbox(prefix_manager)
         self.set_regedit_keys()
         self.setup_x360ce(self.runner_config.get("x360ce-path"))
-        dxvk_manager = dxvk.DXVKManager
         self.setup_dxvk(
             "dxvk",
-            dxvk_manager=dxvk_manager(
+            dxvk_manager=dxvk.DXVKManager(
                 self.prefix_path,
                 arch=self.wine_arch,
                 version=self.runner_config.get("dxvk_version"),
-            ),
+            )
         )
 
         try:
@@ -882,6 +875,11 @@ class wine(Runner):
             env["WINEDEBUG"] = show_debug
         env["WINEARCH"] = self.wine_arch
         env["WINE"] = self.get_executable()
+        if is_gstreamer_build(self.get_executable()):
+            path_64 = os.path.join(WINE_DIR, self.get_version(), "lib64/gstreamer-1.0/")
+            path_32 = os.path.join(WINE_DIR, self.get_version(), "lib/gstreamer-1.0/")
+            if os.path.exists(path_64) or os.path.exists(path_32):
+                env["GST_PLUGIN_SYSTEM_PATH_1_0"] = path_64 + ":" + path_32
         if self.prefix_path:
             env["WINEPREFIX"] = self.prefix_path
 
@@ -894,8 +892,13 @@ class wine(Runner):
         # On AMD, mimic the video memory management behavior of Windows DX12
         # drivers more closely, otherwise d3d12 games will crash and have other
         # funky issues.
+        # RADV_DEBUG is a comma separated list. If it is already set, we want to
+        # append to it.
         if self.runner_config.get("dxvk") and drivers.is_amd():
-            env["RADV_DEBUG"] = "zerovram"
+            if "RADV_DEBUG" not in env or not env["RADV_DEBUG"]:
+                env["RADV_DEBUG"] = "zerovram"
+            elif "zerovram" not in env["RADV_DEBUG"]:
+                env["RADV_DEBUG"] += ",zerovram"
 
         overrides = self.get_dll_overrides()
         if overrides:
@@ -909,8 +912,15 @@ class wine(Runner):
         wine_root = None
         if WINE_DIR:
             wine_root = os.path.dirname(os.path.dirname(wine_path))
+        for proton_path in get_proton_paths():
+            if proton_path in wine_path:
+                wine_root = os.path.dirname(os.path.dirname(wine_path))
+        if "-4." in wine_path or "/4." in wine_path:
+            version = "Ubuntu-18.04"
+        else:
+            version = "legacy"
         return runtime.get_env(
-            version="Ubuntu-18.04",
+            version=version,
             prefer_system_libs=self.system_config.get("prefer_system_libs", True),
             wine_path=wine_root,
         )
