@@ -63,6 +63,7 @@ def is_7zip_supported(path, extractor):
         "wim",
         "xar",
         "z",
+        "auto",
     )
     if extractor:
         return extractor.lower() in supported_extractors
@@ -86,10 +87,10 @@ def guess_extractor(path):
         extractor = "gzip"
     elif path.endswith(".exe"):
         extractor = "exe"
-    elif is_7zip_supported(path, None):
-        extractor = None
+    elif path.endswith(".deb"):
+        extractor = "deb"
     else:
-        raise RuntimeError("Could not extract `%s` - no appropriate extractor found" % path)
+        extractor = None
     return extractor
 
 
@@ -110,10 +111,10 @@ def get_archive_opener(extractor, path):
         opener = "innoextract"
     elif extractor == "exe":
         opener = "exe"
-    elif extractor is None or is_7zip_supported(path, extractor):
-        opener = "7zip"
+    elif extractor == "deb":
+        opener = "deb"
     else:
-        raise RuntimeError("Could not extract `%s` - unknown format specified" % path)
+        opener = "7zip"
     return opener, mode
 
 
@@ -126,8 +127,7 @@ def extract_archive(path, to_directory=".", merge_single=True, extractor=None):
 
     opener, mode = get_archive_opener(extractor, path)
 
-    temp_name = ".extract-" + random_id()
-    temp_path = temp_dir = os.path.join(to_directory, temp_name)
+    temp_path = temp_dir = os.path.join(to_directory, ".extract-%s" % random_id())
     try:
         _do_extract(path, temp_path, opener, mode, extractor)
     except (OSError, zlib.error, tarfile.ReadError, EOFError) as ex:
@@ -179,12 +179,14 @@ def extract_archive(path, to_directory=".", merge_single=True, extractor=None):
 def _do_extract(archive, dest, opener, mode=None, extractor=None):
     if opener == "gz":
         decompress_gz(archive, dest)
-    if opener == "7zip":
+    elif opener == "7zip":
         extract_7zip(archive, dest, archive_type=extractor)
     elif opener == "exe":
         extract_exe(archive, dest)
     elif opener == "innoextract":
         extract_gog(archive, dest)
+    elif opener == "deb":
+        extract_deb(archive, dest)
     else:
         handler = opener(archive, mode)
         handler.extractall(dest)
@@ -209,6 +211,23 @@ def extract_exe(path, dest):
             raise RuntimeError("specified exe is not an archive or GOG setup file")
 
 
+def extract_deb(archive, dest):
+    """Extract the contents of a deb file to a destination folder"""
+    extract_7zip(archive, dest, archive_type="ar")
+    debian_folder = os.path.join(dest, "debian")
+    os.makedirs(debian_folder)
+    shutil.move(os.path.join(dest, "control.tar.gz"), debian_folder)
+    data_file = os.path.join(dest, "data.tar.gz")
+    extractor = "r:gz"
+    if not os.path.exists(data_file):
+        data_file = os.path.join(dest, "data.tar.xz")
+        extractor = "r:xz"
+    handler = tarfile.open(data_file, extractor)
+    handler.extractall(dest)
+    handler.close()
+    os.remove(data_file)
+
+
 def extract_gog(path, dest):
     if check_inno_exe(path):
         decompress_gog(path, dest)
@@ -248,21 +267,19 @@ def decompress_gog(file_path, destination_path):
         raise RuntimeError("innoextract failed to extract GOG setup file")
 
 
-def decompress_gz(file_path, dest_path=None):
+def decompress_gz(file_path, dest_path):
     """Decompress a gzip file."""
     if dest_path:
         dest_filename = os.path.join(dest_path, os.path.basename(file_path[:-3]))
     else:
         dest_filename = file_path[:-3]
+    if not os.path.exists(os.path.dirname(dest_filename)):
+        os.makedirs(os.path.dirname(dest_filename))
 
-    gzipped_file = gzip.open(file_path, "rb")
-    file_content = gzipped_file.read()
-    gzipped_file.close()
-
-    dest_file = open(dest_filename, "wb")
-    dest_file.write(file_content)
-    dest_file.close()
-
+    with open(dest_filename, "wb") as dest_file:
+        gzipped_file = gzip.open(file_path, "rb")
+        dest_file.write(gzipped_file.read())
+        gzipped_file.close()
     return dest_path
 
 
@@ -273,6 +290,6 @@ def extract_7zip(path, dest, archive_type=None):
     if not system.path_exists(_7zip_path):
         raise OSError("7zip is not found in the lutris runtime or on the system")
     command = [_7zip_path, "x", path, "-o{}".format(dest), "-aoa"]
-    if archive_type:
+    if archive_type and archive_type != "auto":
         command.append("-t{}".format(archive_type))
     subprocess.call(command)
